<?php
/**
 * Plugin Name: Skip Checkout for Bookings
 * Plugin URI: https://pluginhive.com/
 * Description: This addon works with WooCommerce Bookings & Appointments plugin and allows customers to place a booking directly form the product page, skipping both cart and checkout.
 * Version: 1.0.2
 * Author: pluginhive
 * Author URI: https://pluginhive.com
 * Text Domain: bookings-and-appointments-for-woocommerce
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

// Define PH_BOOKINGS_MINIMU_DAY_PLUGIN_FILE.
if ( ! defined( 'PH_BOOKINGS_DIRECT_BOOKING_PLUGIN_FILE' ) )
	define( 'PH_BOOKINGS_DIRECT_BOOKING_PLUGIN_FILE', __FILE__ );

	define( 'PH_BOOKING_DIRECT_BOOKING_SETTING_ID', 'ph_booking_direct_booking_from_product' );

function ph_bookings_activation_check_for_direct_booking_addon(){

    if ( !is_plugin_active('ph-bookings-appointments-woocommerce-premium/ph-bookings-appointments-woocommerce-premium.php') ){
        deactivate_plugins( basename( __FILE__ ) );
        wp_die( __("Oops! You tried installing the Skip Checkout for Bookings addon without activating Bookings and Appointments For WooCommerce Premium Plugin. Kindly activate <b>Bookings and Appointments For WooCommerce Premium Plugin</b> and then try again", "bookings-and-appointments-for-woocommerce" ), "", array('back_link' => 1 ));
    }
}

register_activation_hook( __FILE__, 'ph_bookings_activation_check_for_direct_booking_addon' );

//check if woocommerce exists
if ( !class_exists( 'woocommerce' ) || !class_exists('phive_booking_initialze_premium') ) {
    add_action( 'admin_init', 'Ph_Bookings_Direct_Booking_deactivate' );
    if ( ! function_exists( 'Ph_Bookings_Direct_Booking_deactivate' ) ) {
        function Ph_Bookings_Direct_Booking_deactivate() {
            if ( !class_exists( 'woocommerce' ) || !class_exists('phive_booking_initialze_premium') ){
                deactivate_plugins( plugin_basename( __FILE__ ) );
                wp_safe_redirect( admin_url('plugins.php') );

            }
        }
    }
}

if( ! class_exists('Ph_Bookings_Direct_Booking_From_Product') ) {
	class Ph_Bookings_Direct_Booking_From_Product {

		/**
		 * Constructor
		 */
		public function __construct() {
			$this->init();
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array( $this, 'plugin_action_links' ) );
			add_action('wp_footer',array($this,'phive_booking_scripts_range'));
		}

		/**
		 * Init
		 */
		public function init(){
			if( ! class_exists('Ph_Direct_Booking_Product_page') )
				include_once 'inc/front/class-ph-direct-booking-product-page.php';

			include_once 'inc/admin/class-ph-direct-booking-admin-page.php';
		}

		function phive_booking_scripts_range(){
			wp_enqueue_script( 'ph_direct_booking_script', plugins_url( '/resources/js/ph-direct-booking.js', __FILE__ ), array( 'jquery' ) );
			$keys  = array(
				'first_name',
				'last_name',
				'company',
				'address_1',
				'address_2',
				'city',
				'state',
				'postcode',
				'country',
				'phone',
				'email'
			);
		    $customer_id = get_current_user_id();
	    	foreach ( $keys as $key ) 
			{
				$user[ $key ] = (string) get_user_meta( $customer_id,  'billing_' . $key, true );

			}
			
			wp_localize_script( 'ph_direct_booking_script', 'user_details', array("user"=>$user) );
			

		}
		function plugin_action_links( $links ) {
		
			$plugin_links = array(
				'<a href="'.admin_url('admin.php?page=skip-cart-checkout').'" >' . __('Settings', 'bookings-and-appointments-for-woocommerce') . '</a>',
			);
			return array_merge( $plugin_links, $links );
		
		}

	}
}
new Ph_Bookings_Direct_Booking_From_Product();